import path from "path";
import { writeJsonFileSync } from "write-json-file";
import { baseTsConfigContent } from "./configs/tsconfig.js";
import { isInRootFolder, fromRoot, getDirName } from "./utils.js";
const __dirname = getDirName(import.meta.url);
var TsFileType;
(function (TsFileType) {
    TsFileType["Base"] = "base";
    TsFileType["Build"] = "build";
})(TsFileType || (TsFileType = {}));
export const getPathToCreatedTsConfig = (fileType) => {
    return path.join(__dirname, `./configs/tsconfig.${fileType}.json`);
};
export const getPathToBuildTsConfig = () => {
    return getPathToCreatedTsConfig(TsFileType.Build);
};
export const getPathToBaseTsConfig = () => {
    return getPathToCreatedTsConfig(TsFileType.Base);
};
/**
 * Copies config from the @jupiter-tools/tsconfig-jupiter package and set up
 *   automatically declarationDir, outDir, include and exclude paths. These
 *   paths are specific for each project and should be set up typescript to work
 *   properly.
 *
 */
export const setUpTsConfigs = () => {
    const pathToBaseTsConfig = getPathToBaseTsConfig();
    const pathToBuildTsConfig = getPathToBuildTsConfig();
    let includePath = "";
    if (isInRootFolder("src")) {
        includePath = fromRoot("src");
    }
    else if (isInRootFolder("packages")) {
        includePath = fromRoot("packages");
    }
    if (!includePath) {
        throw new Error("Either 'src' or 'packages' directory should contain source code of the package. Neither of them was found.");
    }
    /**
     * Prepare tsconfig.base.json
     *
     */
    writeJsonFileSync(pathToBaseTsConfig, {
        ...baseTsConfigContent,
        include: [includePath],
        exclude: ["coverage", "node_modules", "dist"].map((excludePath) => path.join(fromRoot("."), excludePath)),
    });
    /**
     * Prepare tsconfig.build.json
     *
     */
    writeJsonFileSync(pathToBuildTsConfig, {
        extends: "./tsconfig.base.json",
        compilerOptions: {
            outDir: fromRoot("dist"),
        },
        exclude: ["**/__tests__/", "dist"].map((excludePath) => path.join(fromRoot("."), excludePath)),
    });
};
//# sourceMappingURL=setUpTsConfigs.js.map